#include <ReArchive/types/FileTable.h>
#include <cstring>

using namespace ReArchive;

void FileTable::Append(const FileEntry& file_entry) {
    for (const auto& e : entries)
        if (e.Path() == file_entry.Path())
            return;

    entries.push_back(file_entry);
}

void FileTable::Remove(const FileEntry& file_entry) {
    if (entries.empty())
        return;

    for (int64_t i = 0; i < entries.size(); i++) {
        if (entries[i] == file_entry) {
            entries.erase(entries.begin() + i);
            break;
        }
    }
}

std::vector<unsigned char> FileTable::Serialize(const FileTable& file_table) {
    auto files = file_table.GetEntries();
    int64_t count = files.size();
    auto network_count = htobe64(count);
    std::vector<unsigned char> result(reinterpret_cast<unsigned char*>(&network_count),
                                      reinterpret_cast<unsigned char*>(&network_count) + sizeof(network_count));

    if (files.empty())
        return result;

    for (const auto& file : files) {
        size_t current_size = result.size();
        auto serialization = FileEntry::Serialize(file);

        result.resize(current_size + serialization.size());
        memcpy(result.data() + current_size, serialization.data(), serialization.size());
    }
    return result;
}
